@@ -1,6 +1,3 @@
-import numpy as np
-
-
 def calc_number_digit(number):
     res = number
     digit = 0
@@ -16,21 +13,6 @@ def calc_number_digit(number):
     return 10 ** digit
 
 
-def calc_number_step(number):
-    digit = calc_number_digit(number)
-    n = number / digit
-    while True:
-        if n < 5:
-            digit /= 5
-            n = round(number / digit)
-        elif n > 10:
-            digit *= 2
-            n = round(number / digit)
-        else:
-            break
-    return n, digit
-
-
 def get_num_digit(number):
     int_part, frac_part = str(float(number)).split(".")
     int_digit, frac_digit = len(int_part), len(frac_part)
